@@ -3,12 +3,6 @@ import config.base
 import os
 import re
 
-try:
-  enumerate([0, 1])
-except NameError:
-  def enumerate(l):
-    return zip(range(len(l)), l)
-
 class Configure(config.base.Configure):
   def __init__(self, framework, libraries = []):
     config.base.Configure.__init__(self, framework)
@@ -24,22 +18,23 @@ class Configure(config.base.Configure):
     self.headers      = framework.require('config.headers',      self)
     return
 
-  def getLibArgumentList(self, library):
+  def getLibArgumentList(self, library, with_rpath=True):
     '''Return the proper link line argument for the given filename library as a list of options
       - If the path is empty, return it unchanged
       - If starts with - then return unchanged
       - If the path ends in ".lib" return it unchanged
-      - If the path is absolute and the filename is "lib"<name>, return -L<dir> -l<name>
+      - If the path is absolute and the filename is "lib"<name>, return -L<dir> -l<name> (optionally including rpath flag)
       - If the filename is "lib"<name>, return -l<name>
-      - If the path ends in ".so" return it unchanged       
+      - If the path ends in ".so" return it unchanged
+      - If the path ends in ".o" return it unchanged
       - If the path is absolute, return it unchanged
       - Otherwise return -l<library>'''
     if not library:
       return []
     if library.startswith('${CC_LINKER_SLFLAG}'):
-      return [library]
+      return [library] if with_rpath else []
     if library.startswith('${FC_LINKER_SLFLAG}'):
-      return [library]
+      return [library] if with_rpath else []
     if library.lstrip()[0] == '-':
       return [library]
     if len(library) > 3 and library[-4:] == '.lib':
@@ -50,15 +45,17 @@ class Configure(config.base.Configure):
         flagName  = self.language[-1]+'SharedLinkerFlag'
         flagSubst = self.language[-1].upper()+'_LINKER_SLFLAG'
         dirname   = os.path.dirname(library).replace('\\ ',' ').replace(' ', '\\ ').replace('\\(','(').replace('(', '\\(').replace('\\)',')').replace(')', '\\)')
-        if hasattr(self.setCompilers, flagName) and not getattr(self.setCompilers, flagName) is None:
-          return [getattr(self.setCompilers, flagName)+dirname,'-L'+dirname,'-l'+name]
-        if flagSubst in self.framework.argDB:
-          return [self.framework.argDB[flagSubst]+dirname,'-L'+dirname,'-l'+name]
-        else:
-          return ['-L'+dirname,' -l'+name]
+        if dirname in ['/usr/lib','/lib','/usr/lib64','/lib64']:
+          return [library]
+        if with_rpath:
+          if hasattr(self.setCompilers, flagName) and not getattr(self.setCompilers, flagName) is None:
+            return [getattr(self.setCompilers, flagName)+dirname,'-L'+dirname,'-l'+name]
+          if flagSubst in self.argDB:
+            return [self.argDB[flagSubst]+dirname,'-L'+dirname,'-l'+name]
+        return ['-L'+dirname,'-l'+name]
       else:
         return ['-l'+name]
-    if os.path.splitext(library)[1] == '.so':
+    if os.path.splitext(library)[1] == '.so' or os.path.splitext(library)[1] == '.o':
       return [library]
     if os.path.isabs(library):
       return [library]
@@ -77,6 +74,9 @@ class Configure(config.base.Configure):
   def getDefineName(self, library):
     return 'HAVE_LIB'+self.getLibName(library).upper().replace('-','_').replace('=','_').replace('+','_').replace('.', '_').replace('/','_')
 
+  def getDefineNameFunc(self, funcName):
+    return 'HAVE_'+ funcName.upper()
+
   def haveLib(self, library):
     return self.getDefineName(library) in self.defines
 
@@ -94,28 +94,52 @@ class Configure(config.base.Configure):
 
   def toString(self,libs):
     '''Converts a list of libraries to a string suitable for a linker'''
-    return ' '.join([self.getLibArgument(lib) for lib in libs])
-
-  def toStringNoDupes(self,libs):
-    '''Converts a list of libraries to a string suitable for a linker, removes duplicates'''
     newlibs = []
+    frame = 0
     for lib in libs:
-      newlibs += self.getLibArgumentList(lib)
-    libs = newlibs
-    newlibs = []
-    removedashl = 0
-    for j in libs:
-      # do not remove duplicate -l, because there is a tiny chance that order may matter
-      if j in newlibs and not ( j.startswith('-l') or j == '-framework') : continue
-      # handle special case of -framework frameworkname
-      if j == '-framework': removedashl = 1
-      elif removedashl:
-        j = j[2:]
-        removedashl = 0
-        
-      newlibs.append(j)
+      if frame:
+        newlibs += [lib]
+        frame   = 0
+      elif lib == '-framework':
+        newlibs += [lib]
+        frame = 1
+      else:
+        newlibs += self.getLibArgumentList(lib)
     return ' '.join(newlibs)
 
+  def toStringNoDupes(self,libs,with_rpath=True):
+    '''Converts a list of libraries to a string suitable for a linker, removes duplicates'''
+    '''Moves the flags that can be moved to the beginning of the string but always leaves the libraries and other items that must remain in the same order'''
+    newlibs = []
+    frame = 0
+    for lib in libs:
+      if frame:
+        newlibs += [lib]
+        frame   = 0
+      elif lib == '-framework':
+        newlibs += [lib]
+        frame = 1
+      else:
+        newlibs += self.getLibArgumentList(lib, with_rpath)
+    libs = newlibs
+    newldflags = []
+    newlibs = []
+    frame = 0
+    dupflags = ['-L']
+    flagName  = self.language[-1]+'SharedLinkerFlag'
+    if hasattr(self.setCompilers, flagName) and not getattr(self.setCompilers, flagName) is None:
+      dupflags.append(getattr(self.setCompilers, flagName))
+    for j in libs:
+      # remove duplicate -L, -Wl,-rpath options - and only consecutive -l options
+      if j in newldflags and any([j.startswith(flg) for flg in dupflags]): continue
+      if newlibs and j == newlibs[-1]: continue
+      if j.startswith('-l') or j.endswith('.lib') or j.endswith('.a') or j.endswith('.o') or j == '-Wl,-Bstatic' or j == '-Wl,-Bdynamic' or j == '-Wl,--start-group' or j == '-Wl,--end-group':
+        newlibs.append(j)
+      else:
+        newldflags.append(j)
+    liblist = ' '.join(newldflags + newlibs)
+    return liblist
+
   def getShortLibName(self,lib):
     '''returns the short name for the library. Valid names are foo -lfoo or libfoo.[a,so,lib]'''
     if lib.startswith('-l'):
@@ -130,45 +154,30 @@ class Configure(config.base.Configure):
     # no match - assuming the given name is already in short notation
     return lib
 
-  def check(self, libName, funcs, libDir = None, otherLibs = [], prototype = '', call = '', fortranMangle = 0, cxxMangle = 0):
+  def check(self, libName, funcs, libDir = None, otherLibs = [], prototype = '', call = '', fortranMangle = 0, cxxMangle = 0, cxxLink = 0, functionDefine = 0, examineOutput=lambda ret,out,err:None):
     '''Checks that the library "libName" contains "funcs", and if it does defines HAVE_LIB"libName"
        - libDir may be a list of directories
        - libName may be a list of library names'''
     if not isinstance(funcs,list): funcs = [funcs]
     if not isinstance(libName, list): libName = [libName]
-    for f, funcName in enumerate(funcs):
-      # Handle Fortran mangling
-      if fortranMangle:
-        funcName = self.compilers.mangleFortranFunction(funcName)
-      self.framework.logPrint('Checking for function '+str(funcName)+' in library '+str(libName)+' '+str(otherLibs))
-      if self.language[-1] == 'FC':
-        includes = ''
-      else:
-        includes = '/* Override any gcc2 internal prototype to avoid an error. */\n'
-      # Handle C++ mangling
-      if self.language[-1] == 'Cxx' and not cxxMangle:
-        includes += '''
-#ifdef __cplusplus
-extern "C" {
-#endif
-'''
+    def genPreamble(f, funcName):
       # Construct prototype
-      if not self.language[-1] == 'FC':
-        if prototype:
-          if isinstance(prototype, str):
-            includes += prototype
-          else:
-            includes += prototype[f]
+      if self.language[-1] == 'FC':
+        return ''
+      if prototype:
+        if isinstance(prototype, str):
+          pre = prototype
         else:
-          # We use char because int might match the return type of a gcc2 builtin and its argument prototype would still apply.
-          includes += 'char '+funcName+'();\n'
-      # Handle C++ mangling
-      if self.language[-1] == 'Cxx' and not cxxMangle:
-        includes += '''
-#ifdef __cplusplus
-}
-#endif
-'''
+          pre = prototype[f]
+      else:
+        # We use char because int might match the return type of a gcc2 builtin and its argument prototype would still apply.
+        pre = 'char '+funcName+'();'
+      # Capture the function call in a static function so that any local variables are isolated from
+      # calls to other library functions.
+      return pre + '\nstatic void _check_%s() { %s }' % (funcName, genCall(f, funcName, pre=True))
+    def genCall(f, funcName, pre=False):
+      if self.language[-1] != 'FC' and not pre:
+        return '_check_' + funcName + '();'
       # Construct function call
       if call:
         if isinstance(call, str):
@@ -176,60 +185,136 @@ extern "C" {
         else:
           body = call[f]
       else:
-        body = funcName+'()\n'
-      # Setup link line
-      oldLibs = self.setCompilers.LIBS
-      if libDir:
-        if not isinstance(libDir, list): libDir = [libDir]
-        for dir in libDir:
-          self.setCompilers.LIBS += ' -L'+dir
-      # new libs may/will depend on system libs so list new libs first!
-      # Matt, do not change this without talking to me
-      if libName and otherLibs:
-        self.setCompilers.LIBS = ' '+self.toString(libName+otherLibs) +' '+ self.setCompilers.LIBS
-      elif otherLibs:
-        self.setCompilers.LIBS = ' '+self.toString(otherLibs) +' '+ self.setCompilers.LIBS
+        body = funcName+'()'
+      if self.language[-1] != 'FC':
+        body += ';'
+      return body
+    # Handle Fortran mangling
+    if fortranMangle:
+      funcs = list(map(self.compilers.mangleFortranFunction, funcs))
+    if not funcs:
+      self.logPrint('No functions to check for in library '+str(libName)+' '+str(otherLibs))
+      return True
+    self.logPrint('Checking for functions ['+' '.join(funcs)+'] in library '+str(libName)+' '+str(otherLibs))
+    if self.language[-1] == 'FC':
+      includes = ''
+    else:
+      includes = '/* Override any gcc2 internal prototype to avoid an error. */\n'
+    # Handle C++ mangling
+    if self.language[-1] == 'Cxx' and not cxxMangle:
+      includes += '''
+#ifdef __cplusplus
+extern "C" {
+#endif
+'''
+    includes += '\n'.join([genPreamble(f, fname) for f, fname in enumerate(funcs)])
+    # Handle C++ mangling
+    if self.language[-1] == 'Cxx' and not cxxMangle:
+      includes += '''
+#ifdef __cplusplus
+}
+#endif
+'''
+    body = '\n'.join([genCall(f, fname) for f, fname in enumerate(funcs)])
+    # Setup link line
+    oldLibs = self.setCompilers.LIBS
+    if libDir:
+      if not isinstance(libDir, list): libDir = [libDir]
+      for dir in libDir:
+        self.setCompilers.LIBS += ' -L'+dir
+    # new libs may/will depend on system libs so list new libs first!
+    # Matt, do not change this without talking to me
+    if libName and otherLibs:
+      self.setCompilers.LIBS = ' '+self.toString(libName+otherLibs) +' '+ self.setCompilers.LIBS
+    elif otherLibs:
+      self.setCompilers.LIBS = ' '+self.toString(otherLibs) +' '+ self.setCompilers.LIBS
+    elif libName:
+      self.setCompilers.LIBS = ' '+self.toString(libName) +' '+ self.setCompilers.LIBS
+    if cxxMangle: compileLang = 'Cxx'
+    else:         compileLang = self.language[-1]
+    if cxxLink: linklang = 'Cxx'
+    else: linklang = self.language[-1]
+    self.pushLanguage(compileLang)
+    found = 0
+    if self.checkLink(includes, body, linkLanguage=linklang, examineOutput=examineOutput):
+      found = 1
+      # define the symbol as found
+      if functionDefine: [self.addDefine(self.getDefineNameFunc(fname), 1) for f, fname in enumerate(funcs)]
+      # add to list of found libraries
       elif libName:
-        self.setCompilers.LIBS = ' '+self.toString(libName) +' '+ self.setCompilers.LIBS
-      self.pushLanguage(self.language[-1])
-      found = 0
-      if self.checkLink(includes, body):
-        found = 1
-        # add to list of found libraries
-        if libName:
-          for lib in libName:
-            shortlib = self.getShortLibName(lib)
-            if shortlib: self.addDefine(self.getDefineName(shortlib), 1)
-      self.setCompilers.LIBS = oldLibs
-      self.popLanguage()
-      if not found: return 0
-    return 1
+        for lib in libName:
+          shortlib = self.getShortLibName(lib)
+          if shortlib: self.addDefine(self.getDefineName(shortlib), 1)
+    self.setCompilers.LIBS = oldLibs
+    self.popLanguage()
+    return found
+
+  def checkClassify(self, libName, funcs, libDir=None, otherLibs=[], prototype='', call='', fortranMangle=0, cxxMangle=0, cxxLink=0):
+    '''Recursive decompose to rapidly classify functions as found or missing'''
+    import config
+    def functional(funcs):
+      named = config.NamedInStderr(funcs)
+      if self.check(libName, funcs, libDir, otherLibs, prototype, call, fortranMangle, cxxMangle, cxxLink):
+        return True
+      else:
+        return named.named
+    found, missing = config.classify(funcs, functional)
+    return found, missing
 
   def checkMath(self):
     '''Check for sin() in libm, the math library'''
     self.math = None
     funcs = ['sin', 'floor', 'log10', 'pow']
-    prototypes = ['double sin(double);', 'double floor(double);', 'double log10(double);', 'double pow(double, double);']
-    calls = ['double x = 0,y; y = sin(x);\n', 'double x = 0,y; y = floor(x);\n', 'double x = 0,y; y = log10(x);\n', 'double x = 0,y ; y = pow(x, x);\n']
+    prototypes = ['#include <stdio.h>\ndouble sin(double);',
+                  '#include <stdio.h>\ndouble floor(double);',
+                  '#include <stdio.h>\ndouble log10(double);',
+                  '#include <stdio.h>\ndouble pow(double, double);']
+    calls = ['double x,y; scanf("%lf",&x); y = sin(x); printf("%f",y);\n',
+             'double x,y; scanf("%lf",&x); y = floor(x); printf("%f",y);\n',
+             'double x,y; scanf("%lf",&x); y = log10(x); printf("%f",y);\n',
+             'double x,y; scanf("%lf",&x); y = pow(x,x); printf("%f",y);\n']
     if self.check('', funcs, prototype = prototypes, call = calls):
-      self.logPrint('Math functions are linked in by default')
       self.math = []
     elif self.check('m', funcs, prototype = prototypes, call = calls):
-      self.logPrint('Using libm for the math library')
       self.math = ['libm.a']
-    else:
-      self.logPrint('Warning: No math library found')
+    self.logPrint('CheckMath: using math library '+str(self.math))
     return
 
   def checkMathErf(self):
     '''Check for erf() in libm, the math library'''
-    if not self.math is None and self.check(self.math, ['erf'], prototype = ['double erf(double);'], call = ['double x = 0,y; y = erf(x);\n']):
+    if not self.math is None and self.check(self.math, ['erf'], prototype = ['#include <math.h>'], call = ['double (*checkErf)(double) = erf;double x = 0,y; y = (*checkErf)(x)']):
       self.logPrint('erf() found')
       self.addDefine('HAVE_ERF', 1)
     else:
       self.logPrint('Warning: erf() not found')
     return
 
+  def checkMathTgamma(self):
+    '''Check for tgamma() in libm, the math library'''
+    if not self.math is None and self.check(self.math, ['tgamma'], prototype = ['#include <math.h>'], call = ['double (*checkTgamma)(double) = tgamma;double x = 0,y; y = (*checkTgamma)(x)']):
+      self.logPrint('tgamma() found')
+      self.addDefine('HAVE_TGAMMA', 1)
+    else:
+      self.logPrint('Warning: tgamma() not found')
+    return
+
+  def checkMathFenv(self):
+    '''Checks if <fenv.h> can be used with FE_DFL_ENV'''
+    if not self.math is None and self.check(self.math, ['fesetenv'], prototype = ['#include <fenv.h>'], call = ['fesetenv(FE_DFL_ENV);']):
+      self.addDefine('HAVE_FENV_H', 1)
+    else:
+      self.logPrint('Warning: <fenv.h> with FE_DFL_ENV not found')
+    return
+
+  def checkMathLog2(self):
+    '''Check for log2() in libm, the math library'''
+    if not self.math is None and self.check(self.math, ['log2'], prototype = ['#include <math.h>'], call = ['double (*checkLog2)(double) = log2; double x = 2.5, y = (*checkLog2)(x)']):
+      self.logPrint('log2() found')
+      self.addDefine('HAVE_LOG2', 1)
+    else:
+      self.logPrint('Warning: log2() not found')
+    return
+
   def checkRealtime(self):
     '''Check for presence of clock_gettime() in realtime library (POSIX Realtime extensions)'''
     self.rt = None
@@ -248,12 +333,12 @@ extern "C" {
 
   def checkDynamic(self):
     '''Check for the header and libraries necessary for dynamic library manipulation'''
-    if 'with-dynamic-loading' in self.framework.argDB and not self.framework.argDB['with-dynamic-loading']: return
+    if 'with-dynamic-loading' in self.argDB and not self.argDB['with-dynamic-loading']: return
     self.check(['dl'], 'dlopen')
     self.headers.check('dlfcn.h')
     return
 
-  def checkShared(self, includes, initFunction, checkFunction, finiFunction = None, checkLink = None, libraries = [], initArgs = '&argc, &argv', boolType = 'int', noCheckArg = 0, defaultArg = '', executor = None):
+  def checkShared(self, includes, initFunction, checkFunction, finiFunction = None, checkLink = None, libraries = [], initArgs = '&argc, &argv', boolType = 'int', noCheckArg = 0, defaultArg = '', executor = None, timeout = 60):
     '''Determine whether a library is shared
        - initFunction(int *argc, char *argv[]) is called to initialize some static data
        - checkFunction(int *check) is called to verify that the static data wer set properly
@@ -264,8 +349,8 @@ extern "C" {
       checkLink = self.checkLink
       configObj = self
     else:
-      if hasattr(checkLink, 'im_self'):
-        configObj = checkLink.im_self
+      if hasattr(checkLink, '__self__'):
+        configObj = checkLink.__self__
       else:
         configObj = self
 
@@ -378,21 +463,43 @@ int checkInit(void) {
     oldLibs = self.setCompilers.LIBS
     if self.haveLib('dl'):
       self.setCompilers.LIBS += ' -ldl'
-    if self.checkRun(defaultIncludes, body, defaultArg = defaultArg, executor = executor):
-      isShared = 1
+    isShared = 0
+    try:
+      isShared = self.checkRun(defaultIncludes, body, defaultArg = defaultArg, executor = executor, timeout = timeout)
+    except RuntimeError as e:
+      if executor and str(e).find('Runaway process exceeded time limit') > -1:
+        raise RuntimeError('Timeout: Unable to run MPI program with '+executor+'\n\
+    (1) make sure this is the correct program to run MPI jobs\n\
+    (2) your network may be misconfigured; see https://www.mcs.anl.gov/petsc/documentation/faq.html#PetscOptionsInsertFile\n')
+
     self.setCompilers.LIBS = oldLibs
     if os.path.isfile(lib1Name) and self.framework.doCleanup: os.remove(lib1Name)
     if os.path.isfile(lib2Name) and self.framework.doCleanup: os.remove(lib2Name)
     if isShared:
-      self.framework.logPrint('Library was shared')
+      self.logPrint('Library was shared')
     else:
-      self.framework.logPrint('Library was not shared')
+      self.logPrint('Library was not shared')
     return isShared
 
+  def isBGL(self):
+    '''Returns true if compiler is IBM cross compiler for BGL'''
+    if not hasattr(self, '_isBGL'):
+      self.logPrint('**********Checking if running on BGL/IBM detected')
+      if (self.check('', 'bgl_perfctr_void') or self.check('','ADIOI_BGL_Open')) and self.check('', '_xlqadd'):
+        self.logPrint('*********BGL/IBM detected')
+        self._isBGL = 1
+      else:
+        self.logPrint('*********BGL/IBM test failure')
+        self._isBGL = 0
+    return self._isBGL
+
   def configure(self):
-    map(lambda args: self.executeTest(self.check, list(args)), self.libraries)
+    list(map(lambda args: self.executeTest(self.check, list(args)), self.libraries))
     self.executeTest(self.checkMath)
     self.executeTest(self.checkMathErf)
+    self.executeTest(self.checkMathTgamma)
+    self.executeTest(self.checkMathFenv)
+    self.executeTest(self.checkMathLog2)
     self.executeTest(self.checkRealtime)
     self.executeTest(self.checkDynamic)
     return
