@@ -27,8 +27,6 @@ $     -ksp_guess_type my_initial_guess
 
    Level: advanced
 
-.keywords: KSP, register, KSPGuess
-
 .seealso: KSPGuess, KSPGuessRegisterAll()
 
 @*/
@@ -37,6 +35,7 @@ PetscErrorCode  KSPGuessRegister(const char sname[],PetscErrorCode (*function)(K
   PetscErrorCode ierr;
 
   PetscFunctionBegin;
+  ierr = KSPInitializePackage();CHKERRQ(ierr);
   ierr = PetscFunctionListAdd(&KSPGuessList,sname,function);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
@@ -48,8 +47,6 @@ PetscErrorCode  KSPGuessRegister(const char sname[],PetscErrorCode (*function)(K
 
   Level: advanced
 
-.keywords: KSPGuess, register, all
-
 .seealso: KSPRegisterAll(),  KSPInitializePackage()
 */
 PetscErrorCode KSPGuessRegisterAll(void)
@@ -65,7 +62,16 @@ PetscErrorCode KSPGuessRegisterAll(void)
 }
 
 /*@
-    KSPGuessSetFromOptions
+    KSPGuessSetFromOptions - Sets the options for a KSPGuess from the options database
+
+    Collective on guess
+
+    Input Parameter:
+.    guess - KSPGuess object
+
+   Level: intermediate
+
+.seealso: KSPGuess, KSPGetGuess(), KSPSetGuessType(), KSPGuessType
 @*/
 PetscErrorCode KSPGuessSetFromOptions(KSPGuess guess)
 {
@@ -80,15 +86,13 @@ PetscErrorCode KSPGuessSetFromOptions(KSPGuess guess)
 /*@
    KSPGuessDestroy - Destroys KSPGuess context.
 
-   Collective on KSPGuess
+   Collective on kspGuess
 
    Input Parameter:
 .  guess - initial guess object
 
    Level: beginner
 
-.keywords: KSP, destroy
-
 .seealso: KSPGuessCreate(), KSPGuess, KSPGuessType
 @*/
 PetscErrorCode  KSPGuessDestroy(KSPGuess *guess)
@@ -108,7 +112,7 @@ PetscErrorCode  KSPGuessDestroy(KSPGuess *guess)
 /*@C
    KSPGuessView - View the KSPGuess object
 
-   Logically Collective on KSPGuess
+   Logically Collective on guess
 
    Input Parameters:
 +  guess  - the initial guess object for the Krylov method
@@ -147,7 +151,7 @@ PetscErrorCode  KSPGuessView(KSPGuess guess, PetscViewer view)
 /*@
    KSPGuessCreate - Creates the default KSPGuess context.
 
-   Collective on MPI_Comm
+   Collective
 
    Input Parameter:
 .  comm - MPI communicator
@@ -160,8 +164,6 @@ PetscErrorCode  KSPGuessView(KSPGuess guess, PetscViewer view)
 
    Level: beginner
 
-.keywords: KSP, create, context
-
 .seealso: KSPSolve(), KSPGuessDestroy(), KSPGuess, KSPGuessType, KSP
 @*/
 PetscErrorCode  KSPGuessCreate(MPI_Comm comm,KSPGuess *guess)
@@ -182,7 +184,7 @@ PetscErrorCode  KSPGuessCreate(MPI_Comm comm,KSPGuess *guess)
 /*@C
    KSPGuessSetType - Sets the type of a KSPGuess
 
-   Logically Collective on KSPGuess
+   Logically Collective on guess
 
    Input Parameters:
 +  guess - the initial guess object for the Krylov method
@@ -236,8 +238,6 @@ PetscErrorCode  KSPGuessSetType(KSPGuess guess, KSPGuessType type)
 
    Level: intermediate
 
-.keywords: KSP, get, method, name
-
 .seealso: KSPGuessSetType()
 @*/
 PetscErrorCode  KSPGuessGetType(KSPGuess guess,KSPGuessType *type)
@@ -252,7 +252,7 @@ PetscErrorCode  KSPGuessGetType(KSPGuess guess,KSPGuessType *type)
 /*@
     KSPGuessUpdate - Updates the guess object with the current solution and rhs vector
 
-   Collective on KSPGuess
+   Collective on guess
 
    Input Parameter:
 +  guess - the initial guess context
@@ -261,8 +261,6 @@ PetscErrorCode  KSPGuessGetType(KSPGuess guess,KSPGuessType *type)
 
    Level: intermediate
 
-.keywords: KSP, get, method, name
-
 .seealso: KSPGuessCreate(), KSPGuess
 @*/
 PetscErrorCode  KSPGuessUpdate(KSPGuess guess, Vec rhs, Vec sol)
@@ -280,7 +278,7 @@ PetscErrorCode  KSPGuessUpdate(KSPGuess guess, Vec rhs, Vec sol)
 /*@
     KSPGuessFormGuess - Form the initial guess
 
-   Collective on KSPGuess
+   Collective on guess
 
    Input Parameter:
 +  guess - the initial guess context
@@ -289,8 +287,6 @@ PetscErrorCode  KSPGuessUpdate(KSPGuess guess, Vec rhs, Vec sol)
 
    Level: intermediate
 
-.keywords: KSP, get, method, name
-
 .seealso: KSPGuessCreate(), KSPGuess
 @*/
 PetscErrorCode  KSPGuessFormGuess(KSPGuess guess, Vec rhs, Vec sol)
@@ -308,15 +304,13 @@ PetscErrorCode  KSPGuessFormGuess(KSPGuess guess, Vec rhs, Vec sol)
 /*@
     KSPGuessSetUp - Setup the initial guess object
 
-   Collective on KSPGuess
+   Collective on guess
 
    Input Parameter:
 -  guess - the initial guess context
 
    Level: intermediate
 
-.keywords: KSP, get, method, name
-
 .seealso: KSPGuessCreate(), KSPGuess
 @*/
 PetscErrorCode  KSPGuessSetUp(KSPGuess guess)
