@@ -6,8 +6,6 @@ static char help[] = "Tests MatGetRowMax(), MatGetRowMin(), MatGetRowMaxAbs()\n"
 #define M 5
 #define N 6
 
-#undef __FUNCT__
-#define __FUNCT__ "main"
 int main(int argc,char **args)
 {
   Mat            A;
@@ -20,7 +18,7 @@ int main(int argc,char **args)
   PetscMPIInt    size;
   PetscBool      doTest=PETSC_TRUE;
 
-  PetscInitialize(&argc,&args,(char*)0,help);
+  ierr = PetscInitialize(&argc,&args,(char*)0,help);if (ierr) return ierr;
   ierr = MPI_Comm_size(PETSC_COMM_WORLD,&size);CHKERRQ(ierr);
 
   ierr = MatCreate(PETSC_COMM_WORLD,&A);CHKERRQ(ierr);
@@ -68,7 +66,7 @@ int main(int argc,char **args)
 
   } else {
     ierr = MatGetType(A,&type);CHKERRQ(ierr);
-    ierr = PetscPrintf(PETSC_COMM_WORLD,"\nMatrix type: %s\n",type);
+    ierr = PetscPrintf(PETSC_COMM_WORLD,"\nMatrix type: %s\n",type);CHKERRQ(ierr);
     /* AIJ */
     ierr = PetscObjectTypeCompare((PetscObject)A,MATMPIAIJ,&doTest);CHKERRQ(ierr);
     if (doTest) {
@@ -111,6 +109,23 @@ int main(int argc,char **args)
   ierr = VecDestroy(&maxabs);CHKERRQ(ierr);
   ierr = MatDestroy(&A);CHKERRQ(ierr);
   ierr = PetscFinalize();
-  return 0;
+  return ierr;
 }
 
+
+
+/*TEST
+
+   test:
+      output_file: output/ex114.out
+
+   test:
+      suffix: 2
+      nsize: 2
+
+   test:
+      suffix: 3
+      nsize: 2
+      args: -mat_type baij
+
+TEST*/
