@@ -197,7 +197,7 @@ int main(int argc,char **argv)
        - Set timestepping duration info
      Then set runtime options, which can override these defaults.
      For example,
-          -ts_max_steps <maxsteps> -ts_final_time <maxtime>
+          -ts_max_steps <maxsteps> -ts_max_time <maxtime>
      to override the defaults set by TSSetMaxSteps()/TSSetMaxTime().
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
@@ -518,3 +518,10 @@ PetscErrorCode MyBCRoutine(TS ts,PetscReal t,Vec f,void *ctx)
 
   return 0;
 }
+
+/*TEST
+
+    test:
+      args: -nox -ts_max_steps 4
+
+TEST*/
